==> ec-rider0.8.1.tar.gz: ec-rider0.8.1/ec_admin/app/helpers/ec_rider/ec_helper/user_login_tag.rb <==
# -*- coding: utf-8 -*-
require 'ec_rider/ec_helper'

module EcRider
  module EcHelper
    module UserLoginTag
      extend MethodDescription

      BIND_OPTION_METHODS = [
        :name_last, :name_first, :kana_name_last, :kana_name_last, :honorific_prefix, :full_name
      ]

      def session
        @template.__send__(:session)
      end

      desc <<-EOS
        [概要: ログイン済みならばその中身を実行します。]
        [引数: なし]
        [戻り値: なし]
        [使用例:
         {{{
         <ec:if_logged_in> <ec:kanji_family_name/>さん </ec:if_logged_in>
          　　⇒ ログイン済みの場合、漢字名（姓）を表示
          }}}
        ]
      EOS
      def if_logged_in(*args, &block)
        if @template.logged_in?
          yield
        end
      end

      desc <<-EOS
        [概要: 未ログインならばその中身を実行します。]
        [引数: なし]
        [戻り値: なし]
        [使用例:
          {{{
          <ec:if_not_logged_in> ゲストさん </ec:if_logged_in>
          　　⇒ 未ログインの場合「ゲストさん」を表示
          }}}
        ]
      EOS
      def if_not_logged_in(*args, &block)
        unless @template.logged_in?
          yield
        end
      end

      desc <<-EOS
        [旧名称: kanji_family_name（非推奨）]
        [概要:漢字名（姓）を表示します。住所が日本以外の会員の場合はアルファベットで姓が表示されます。]
        [引数:なし]
        [戻り値:ログインユーザーの漢字名（姓）]
        [使用例:{{{<ec:name_last/>}}}]
      EOS
      def name_last(*args, &block)
        ERB::Util.h(@template.current_user.name_last) if @template.current_user
      end
      alias_method :kanji_family_name, :name_last

      desc <<-EOS
        [旧名称: name_first（非推奨）]
        [概要:漢字名（名）を表示します。住所が日本以外の会員の場合はアルファベットで名が表示されます。]
        [引数:なし]
        [戻り値:ログインユーザーの漢字名（名）]
        [使用例:{{{<ec:name_first/>}}}]
      EOS
      def name_first(*args, &block)
        ERB::Util.h(@template.current_user.name_first) if @template.current_user
      end
      alias_method :kanji_name, :name_first

      desc <<-EOS
        [旧名称: kana_family_name（非推奨）]
        [概要:カナ名（姓）を表示します。住所が日本以外の会員の場合は何も表示されません。]
        [引数:なし]
        [戻り値:ログインユーザーのカナ名（姓）]
        [使用例:{{{<ec:kana_name_last/>}}}]
      EOS
      def kana_name_last(*args, &block)
        ERB::Util.h(@template.current_user.kana_name_last) if @template.current_user
      end
      alias_method :kana_family_name, :kana_name_last

      desc <<-EOS
        [旧名称: kana_name（非推奨）]
        [概要:カナ名（名）を表示します。住所が日本以外の会員の場合は何も表示されません。]
        [引数:なし]
        [戻り値:ログインユーザーのカナ名（名）]
        [使用例:{{{<ec:kana_name_first/>}}}]
      EOS
      def kana_name_first(*args, &block)
        ERB::Util.h(@template.current_user.kana_name_first) if @template.current_user
      end
      alias_method :kana_name, :kana_name_first

      desc <<-EOS
        [概要:ログインユーザーへの敬称(英語)を表示します。男性なら"Mr."で、女性の場合は"Ms."を返します。]
        [引数:なし]
        [戻り値:ログインユーザーへの敬称]
        [使用例:{{{<ec:honorific_prefix/>}}}]
      EOS
      def honorific_prefix(*args, &block)
        @template.current_user.honorific_prefix if @template.current_user
      end

      desc <<-EOS
        [概要:ログインユーザーのフルネームを表示します。日本語サイト内かつユーザーの住所が日本の場合は"姓 名"で、それ以外の場合は"名 姓"でフォーマットされます。]
        [引数:なし]
        [戻り値:ログインユーザーのフルネーム]
        [使用例:{{{<ec:full_name/>}}}]
      EOS
      def full_name(*args, &block)
        ERB::Util.h(@template.current_user.fullname) if @template.current_user
      end

      private
      def link_with_image_or_default_msg_block(url, msg_key, options = {}, &block)
        if src = options.delete(:src)
          link_to(@template.image_tag(src, options), url)
        else
          text = options.delete(:text) # 必ずdeleteしないとaタグの属性に出力されてしまいます。
          text = @template.capture(&block) if block_given? # ブロックが渡されたら上書き。
          text ||= I18n.t(msg_key) # 何も指定されてなかったらデフォルトをconfig/loclaesのyamlから。
          result = link_to(text, url, options)
          # ブロックが渡されたメソッド(空でない中身を持つecタグ)は <%= %> ではなく <% %>で出力されるので、
          # 結果をoutput_bufferに出力するようにconcatします
          @template.concat(result) if block_given?
          result
        end
      end

      public

      desc <<-EOS
        [旧名称: member_registration_link（非推奨）]
        [概要: 「新規会員登録」リンクを表示します。]
        [引数 href(任意): 遷移先URLを指定します。]
        [引数 src(任意): {{{画像ファイルのパスまたはURLを指定します。
          ファイルマネージャでアップロードしたファイルの場合、cmsフォルダは省略できます。}}}]
        [引数 (オプション): 画像のHTMLオプションを指定します。]
        [戻り値: 新規会員登録へのリンク]
        [使用例:
          {{{
          <ec:link_to_member_registration src="member_registration.gif" width="190" height="31" alt="新規会員登録"/>　（画像リンク）
          <ec:link_to_member_registration text="新規会員登録"/>（文字リンク）
          <ec:link_to_member_registration > 新規会委員登録はこちら</ec:link_to_member_registration>
          }}}
        ]
      EOS
      def link_to_member_registration(*args, &block)
        link_with_image_or_default_msg_block(
          {:controller => 'account', :action => 'policy_information'},
          "activerecord.errors.messages.NM990014", args.shift || {}, &block)
      end
      # 互換性のために古い名前も残しておきます。
      alias_method :member_registration_link, :link_to_member_registration

      desc <<-EOS
        [旧名称: login_link（非推奨）]
        [概要: 「会員専用ページ」リンクを表示します。]
        [引数 href(任意): 遷移先URLを指定します。]
        [引数 src(任意): {{{画像ファイルのパスまたはURLを指定します。
          ファイルマネージャでアップロードしたファイルの場合、cmsフォルダは省略できます。}}}]
        [引数 (オプション): 画像のHTMLオプションを指定します。]
        [戻り値: 会員専用ページへのリンク]
        [使用例:
          {{{
          <ec:link_to_login src="login.gif" width="190" height="31" alt="新規会員登録" class="member"/>　（画像リンク）
          <ec:link_to_login text="ログイン"/>（文字リンク）
          }}}
        ]
      EOS
      def link_to_login(*args, &block)
        link_with_image_or_default_msg_block(
          {:controller => 'account', :action => 'login'},
          "activerecord.errors.messages.NM990015", args.shift || {}, &block)
      end
      # 互換性のために古い名前も残しておきます。
      alias_method :login_link, :link_to_login

      desc <<-EOS
        [旧名称: logout_link（非推奨）]
        [概要: 「ログアウト」リンクを表示します。]
        [引数 href(任意): 遷移先URLを指定します。]
        [引数 src(任意): {{{画像ファイルのパスまたはURLを指定します。
          ファイルマネージャでアップロードしたファイルの場合、cmsフォルダは省略できます。}}}]
        [引数 (オプション): 画像のHTMLオプションを指定します。]
        [戻り値 ログアウトへのリンク]
        [使用例:
          {{{
          <ec:link_to_logout src="logout.gif" width="190" height="31" alt="ログアウト" class="member"/>　（画像リンク）
          <ec:link_to_logout text="ログアウト"/>（文字リンク）
          }}}
        ]
      EOS
      def link_to_logout(*args, &block)
        link_with_image_or_default_msg_block(
          {:controller => 'account', :action => 'logout'},
          "activerecord.errors.messages.NM990016", args.shift || {}, &block)
      end
      # 互換性のために古い名前も残しておきます。
      alias_method :logout_link, :link_to_logout


      desc <<-EOS
        [概要: パスワード再設定画面へのリンクを表示します。]
        [引数 (オプション): リンクのHTMLオプションを指定します。]
        [戻り値: パスワード再設定画面へのリンク]
        [使用例：
          {{{
          <ec:link_to_remider text="パスワードを忘れた時は？"/>
          <ec:link_to_remider>パスワードを忘れた時は？ </ec:link_to_remider>
          }}}
        ]
      EOS
      def link_to_remider(*args, &block)
        options = {
          :href => @template.url_for(:controller => :reminder, :action => :index)
        }.update(args.shift || {})
        link(options, &block)
      end

      desc <<-EOS
        [概要:ログインしていない場合またはログイン会員の住所が日本であればその中身を実行します。]
        [引数:なし]
        [戻り値:なし]
        [使用例:
           {{{
           <ec:if_user_lives_in_japan>
             <ec:inquiry_form_name_last/><ec:inquiry_form_name_first/>
           </ec:if_user_lives_in_japan>
           }}}
           ⇒ ログイン会員の住所が日本の場合は名前（姓）、名前（名）の順で入力欄を表示します。
        ]
      EOS
      def if_user_lives_in_japan(*args, &block)
        if !@template.logged_in? || @template.current_user.user_address.country_code == 'JP'
          yield
        end
      end

      desc <<-EOS
        [概要:ログイン会員の住所が日本でなければその中身を実行します。]
        [引数:なし]
        [戻り値:なし]
        [使用例:
           {{{
           <ec:unless_user_lives_in_japan>
             <ec:inquiry_form_name_first/><ec:inquiry_form_name_last/>
           </ec:unless_user_lives_in_japan>
           }}}
           ⇒ ログイン会員の住所が日本の場合は名前（名）、名前（姓）との入力欄を表示します。
        ]
      EOS
      def unless_user_lives_in_japan(*args, &block)
        if @template.logged_in? && @template.current_user.user_address.country_code != 'JP'
          yield
        end
      end

      desc <<-EOS
        [概要:ログイン会員の属性の条件にマッチするバナーを繰り返します。]
        [引数 banner_code(必須):管理画面で設定したバナーのコードを入力します。]
        [引数 display_qty(必須):表示するバナーの個数を設定します。]
        [戻り値:設定したバナーコードのバナー]
        [使用例:
           {{{
              <ec:banners_for banner_code="0000001" display_qty="6">
                <ec:banner_link/>
              </ec:banners_for>
           }}}
           ⇒ バナーコード｢00001｣のバナー条件からログイン会員にマッチするバナーを表示します。
        ]
      EOS
      def banners_for(*args, &block)
        banner_code, display_qty, options = extract(args, :banner_code => "", :display_qty => nil)
        raise UsageError, "banner_codeを設定してください。" unless banner_code
        raise UsageError, "display_qtyを設定してください。" unless display_qty
        if @template.logged_in? && @template.current_user
          user = @template.current_user
        else
          user = User.new()
        end
        @banners = Banner.banner_group(banner_code, user, display_qty)
        begin
          _each_with_index(:@banners, :@banner, :@index) do
            @template.concat(@template.capture(&block))
          end
        ensure
          @banners = nil
        end
      end

      desc <<-EOS
        [概要:バナーのタイトルを表示します。banners_for内で使用してください。urlの指定がある場合のみリンクタグに変換されます。]
        [引数:no_link(任意) urlが指定されていてもこの引数を付けることでテキストとして表示されます。]
        [戻り値:設定したバナーコードのバナー]
        [使用例:
           {{{
              <ec:banners_for banner_code="0000001" display_qty="6">
                <ec:banner_title_link class="class_A"/>
              </ec:banners_for>
　　　　　　　　　　　⇒　urlが設定されている場合、そのurlにリンクするリンクバナー(タイトル)を表示します。
              <ec:banners_for banner_code="0000001" display_qty="6">
                <ec:banner_title_link no_link="true" class="class_A"/>
              </ec:banners_for>
　　　　　　　　　　　⇒　テキストバナータイトル(必ずテキスト表示されます。)
           }}}
           ⇒ バナーコード｢00001｣のバナー条件からログイン会員にマッチするバナーリンクを表示します。
        ]
      EOS
      def banner_title_link(*args)
        raise UsageError, "bannerはec:banners_forの中で使用してください" unless @banner
        no_link, options = extract(args, :no_link => nil)
        display = @banner.display_for(I18n.locale.to_s)
        return "" if display.nil?
        link_url = @banner.link_url
        if @banner.type_key == :image
          path = '/' + display.image_public_path
          image_or_text = @template.image_tag(path, :alt => display.image_alt)
        else
          image_or_text = display.text_title
        end
        return (!no_link.nil? || link_url.blank?) ? image_or_text : link_to(image_or_text, link_url, options)
      end
      desc <<-EOS
        [概要:バナーの詳細を表示します。banners_for内で使用してください。urlの指定がある場合のみリンクタグに変換されます。]
        [引数:no_link(任意) urlが指定されていてもこの引数を付けることでテキストとして表示されます。]
        [戻り値:設定したバナーコードのバナー]
        [使用例:
           {{{
              <ec:banners_for banner_code="0000001" display_qty="6">
                <ec:banner_link class="class_A"/>
              </ec:banners_for>
　　　　　　　　　　　⇒　urlが設定されている場合、そのurlにリンクするリンクバナー(詳細)を表示します。
              <ec:banners_for banner_code="0000001" display_qty="6">
                <ec:banner_link no_link="true" class="class_A"/>
              </ec:banners_for>
　　　　　　　　　　　⇒　テキストバナー詳細(必ずテキスト表示されます。)
           }}}
           ⇒ バナーコード｢00001｣のバナー条件からログイン会員にマッチするバナーリンクを表示します。
        ]
      EOS
      def banner_link(*args)
        raise UsageError, "bannerはec:banners_forの中で使用してください" unless @banner
        no_link, options = extract(args, :no_link => nil)
        display = @banner.display_for(I18n.locale.to_s)
        return "" if display.nil?
        link_url = @banner.link_url
        if @banner.type_key == :image
          path = '/' + display.image_public_path
          image_or_text = @template.image_tag(path, :alt => display.image_alt)
        else
          image_or_text = display.text_description
        end
        return (!no_link.nil? || link_url.blank?) ? image_or_text : link_to(image_or_text, link_url, options)
      end
      
    end
  end
end

==> ec-rider0.8.2.tar.gz: ec-rider0.8.2/ec_admin/app/helpers/ec_rider/ec_helper/user_login_tag.rb <==
# -*- coding: utf-8 -*-
require 'ec_rider/ec_helper'

module EcRider
  module EcHelper
    module UserLoginTag
      extend MethodDescription

      USER_LOGIN_TAG_BIND_OPTION_METHODS = [
        :name_last, :name_first, :kana_name_last, :kana_name_first, :honorific_prefix, :full_name
      ]

      def session
        @template.__send__(:session)
      end

      desc <<-EOS
        [概要: ログイン済みならばその中身を実行します。]
        [引数: なし]
        [戻り値: なし]
        [使用例:
         {{{
         <ec:if_logged_in> <ec:kanji_family_name/>さん </ec:if_logged_in>
          　　⇒ ログイン済みの場合、漢字名（姓）を表示
          }}}
        ]
      EOS
      def if_logged_in(*args, &block)
        if @template.logged_in?
          yield
        end
      end

      desc <<-EOS
        [概要: 未ログインならばその中身を実行します。]
        [引数: なし]
        [戻り値: なし]
        [使用例:
          {{{
          <ec:if_not_logged_in> ゲストさん </ec:if_logged_in>
          　　⇒ 未ログインの場合「ゲストさん」を表示
          }}}
        ]
      EOS
      def if_not_logged_in(*args, &block)
        unless @template.logged_in?
          yield
        end
      end

      desc <<-EOS
        [旧名称: kanji_family_name（非推奨）]
        [概要:漢字名（姓）を表示します。住所が日本以外の会員の場合はアルファベットで姓が表示されます。]
        [引数:なし]
        [戻り値:ログインユーザーの漢字名（姓）]
        [使用例:{{{<ec:name_last/>}}}]
      EOS
      def name_last(*args, &block)
        ERB::Util.h(@template.current_user.name_last) if @template.current_user
      end
      alias_method :kanji_family_name, :name_last

      desc <<-EOS
        [旧名称: name_first（非推奨）]
        [概要:漢字名（名）を表示します。住所が日本以外の会員の場合はアルファベットで名が表示されます。]
        [引数:なし]
        [戻り値:ログインユーザーの漢字名（名）]
        [使用例:{{{<ec:name_first/>}}}]
      EOS
      def name_first(*args, &block)
        ERB::Util.h(@template.current_user.name_first) if @template.current_user
      end
      alias_method :kanji_name, :name_first

      desc <<-EOS
        [旧名称: kana_family_name（非推奨）]
        [概要:カナ名（姓）を表示します。住所が日本以外の会員の場合は何も表示されません。]
        [引数:なし]
        [戻り値:ログインユーザーのカナ名（姓）]
        [使用例:{{{<ec:kana_name_last/>}}}]
      EOS
      def kana_name_last(*args, &block)
        ERB::Util.h(@template.current_user.kana_name_last) if @template.current_user
      end
      alias_method :kana_family_name, :kana_name_last

      desc <<-EOS
        [旧名称: kana_name（非推奨）]
        [概要:カナ名（名）を表示します。住所が日本以外の会員の場合は何も表示されません。]
        [引数:なし]
        [戻り値:ログインユーザーのカナ名（名）]
        [使用例:{{{<ec:kana_name_first/>}}}]
      EOS
      def kana_name_first(*args, &block)
        ERB::Util.h(@template.current_user.kana_name_first) if @template.current_user
      end
      alias_method :kana_name, :kana_name_first

      desc <<-EOS
        [概要:ログインユーザーへの敬称(英語)を表示します。男性なら"Mr."で、女性の場合は"Ms."を返します。]
        [引数:なし]
        [戻り値:ログインユーザーへの敬称]
        [使用例:{{{<ec:honorific_prefix/>}}}]
      EOS
      def honorific_prefix(*args, &block)
        @template.current_user.honorific_prefix if @template.current_user
      end

      desc <<-EOS
        [概要:ログインユーザーのフルネームを表示します。日本語サイト内かつユーザーの住所が日本の場合は"姓 名"で、それ以外の場合は"名 姓"でフォーマットされます。]
        [引数:なし]
        [戻り値:ログインユーザーのフルネーム]
        [使用例:{{{<ec:full_name/>}}}]
      EOS
      def full_name(*args, &block)
        ERB::Util.h(@template.current_user.fullname) if @template.current_user
      end

      desc <<-EOS
        [概要:ログインユーザーの会員ランクを表示します。]
        [引数:なし]
        [戻り値:ログインユーザーの会員ランク]
        [使用例:{{{<ec:user_rank/>}}}]
      EOS
      def user_rank(*args, &block)
        user_rank_display = @template.current_user.rank.displays.select{|display| display.locale == I18n.locale.to_s}[0]
        return user_rank_display.name unless user_rank_display.nil?
      end

      private
      def link_with_image_or_default_msg_block(url, msg_key, options = {}, &block)
        if src = options.delete(:src)
          link_to(@template.image_tag(src, options), url)
        else
          text = options.delete(:text) # 必ずdeleteしないとaタグの属性に出力されてしまいます。
          text = @template.capture(&block) if block_given? # ブロックが渡されたら上書き。
          text ||= I18n.t(msg_key) # 何も指定されてなかったらデフォルトをconfig/loclaesのyamlから。
          result = link_to(text, url, options)
          # ブロックが渡されたメソッド(空でない中身を持つecタグ)は <%= %> ではなく <% %>で出力されるので、
          # 結果をoutput_bufferに出力するようにconcatします
          @template.concat(result) if block_given?
          result
        end
      end

      public

      desc <<-EOS
        [旧名称: member_registration_link（非推奨）]
        [概要: 「新規会員登録」リンクを表示します。]
        [引数 href(任意): 遷移先URLを指定します。]
        [引数 src(任意): {{{画像ファイルのパスまたはURLを指定します。
          ファイルマネージャでアップロードしたファイルの場合、cmsフォルダは省略できます。}}}]
        [引数 (オプション): 画像のHTMLオプションを指定します。]
        [戻り値: 新規会員登録へのリンク]
        [使用例:
          {{{
          <ec:link_to_member_registration src="member_registration.gif" width="190" height="31" alt="新規会員登録"/>　（画像リンク）
          <ec:link_to_member_registration text="新規会員登録"/>（文字リンク）
          <ec:link_to_member_registration > 新規会委員登録はこちら</ec:link_to_member_registration>
          }}}
        ]
      EOS
      def link_to_member_registration(*args, &block)
        link_with_image_or_default_msg_block(
          {:controller => 'account', :action => 'policy_information'},
          "activerecord.errors.messages.NM990014", args.shift || {}, &block)
      end
      # 互換性のために古い名前も残しておきます。
      alias_method :member_registration_link, :link_to_member_registration

      desc <<-EOS
        [旧名称: login_link（非推奨）]
        [概要: 「会員専用ページ」リンクを表示します。]
        [引数 href(任意): 遷移先URLを指定します。]
        [引数 src(任意): {{{画像ファイルのパスまたはURLを指定します。
          ファイルマネージャでアップロードしたファイルの場合、cmsフォルダは省略できます。}}}]
        [引数 (オプション): 画像のHTMLオプションを指定します。]
        [戻り値: 会員専用ページへのリンク]
        [使用例:
          {{{
          <ec:link_to_login src="login.gif" width="190" height="31" alt="新規会員登録" class="member"/>　（画像リンク）
          <ec:link_to_login text="ログイン"/>（文字リンク）
          }}}
        ]
      EOS
      def link_to_login(*args, &block)
        link_with_image_or_default_msg_block(
          {:controller => 'account', :action => 'login'},
          "activerecord.errors.messages.NM990015", args.shift || {}, &block)
      end
      # 互換性のために古い名前も残しておきます。
      alias_method :login_link, :link_to_login

      desc <<-EOS
        [旧名称: logout_link（非推奨）]
        [概要: 「ログアウト」リンクを表示します。]
        [引数 href(任意): 遷移先URLを指定します。]
        [引数 src(任意): {{{画像ファイルのパスまたはURLを指定します。
          ファイルマネージャでアップロードしたファイルの場合、cmsフォルダは省略できます。}}}]
        [引数 (オプション): 画像のHTMLオプションを指定します。]
        [戻り値 ログアウトへのリンク]
        [使用例:
          {{{
          <ec:link_to_logout src="logout.gif" width="190" height="31" alt="ログアウト" class="member"/>　（画像リンク）
          <ec:link_to_logout text="ログアウト"/>（文字リンク）
          }}}
        ]
      EOS
      def link_to_logout(*args, &block)
        link_with_image_or_default_msg_block(
          {:controller => 'account', :action => 'logout'},
          "activerecord.errors.messages.NM990016", args.shift || {}, &block)
      end
      # 互換性のために古い名前も残しておきます。
      alias_method :logout_link, :link_to_logout


      desc <<-EOS
        [概要: パスワード再設定画面へのリンクを表示します。]
        [引数 (オプション): リンクのHTMLオプションを指定します。]
        [戻り値: パスワード再設定画面へのリンク]
        [使用例：
          {{{
          <ec:link_to_remider>パスワードを忘れた時は？ </ec:link_to_remider>
          }}}
        ]
      EOS
      def link_to_reminder(*args, &block)
        text, html_options = extract(args, :text => nil)
        params = @template.send(:params)
        back_to_url = {:controller => params[:controller], :action => params[:action]}
        options = {:controller => :reminder, :action => :index, :back_to_url => back_to_url}
        text = @template.capture(&block) if block_given?
        result = link_to(text, options, html_options) if text
        # ブロックが渡されたメソッド(空でない中身を持つecタグ)は <%= %> ではなく <% %>で出力されるので、
        # 結果をoutput_bufferに出力するようにconcatします
        @template.concat(result) if result
      end
      alias_method :link_to_remider, :link_to_reminder

      desc <<-EOS
        [概要:ログインしていない場合またはログイン会員の住所が日本であればその中身を実行します。]
        [引数:なし]
        [戻り値:なし]
        [使用例:
           {{{
           <ec:if_user_lives_in_japan>
             <ec:inquiry_form_name_last/><ec:inquiry_form_name_first/>
           </ec:if_user_lives_in_japan>
           }}}
           ⇒ ログイン会員の住所が日本の場合は名前（姓）、名前（名）の順で入力欄を表示します。
        ]
      EOS
      def if_user_lives_in_japan(*args, &block)
        if !@template.logged_in? || @template.current_user.user_address.country_code == 'JP'
          yield
        end
      end

      desc <<-EOS
        [概要:ログイン会員の住所が日本でなければその中身を実行します。]
        [引数:なし]
        [戻り値:なし]
        [使用例:
           {{{
           <ec:unless_user_lives_in_japan>
             <ec:inquiry_form_name_first/><ec:inquiry_form_name_last/>
           </ec:unless_user_lives_in_japan>
           }}}
           ⇒ ログイン会員の住所が日本の場合は名前（名）、名前（姓）との入力欄を表示します。
        ]
      EOS
      def unless_user_lives_in_japan(*args, &block)
        if @template.logged_in? && @template.current_user.user_address.country_code != 'JP'
          yield
        end
      end
    end
  end
end
